import sys
import os
from sqlalchemy import create_engine, engine_from_config, pool
from alembic import context

# Add the `xcap` directory to the Python path so we can import our modules
sys.path.append(os.path.abspath(os.path.join(os.path.dirname(__file__), "../xcap")))

# Import the base class and model metadata from xcap.db
from xcap.db.database import Base  # This imports the Base class from where you define all your models
from xcap.db.models import XCAPResource  # Import your model(s)

# Alembic configuration object
config = context.config

# This will be used for the 'target_metadata' argument to Alembic, which provides the metadata
# for your database models. It points to the Base's metadata.
target_metadata = Base.metadata

# Function to include SQLAlchemy's engine configuration
def run_migrations_online():
    """Run migrations in 'online' mode."""
    # This part connects to the database.
    connectable = engine_from_config(
        config.get_section(config.config_ini_section),
        prefix='sqlalchemy.',
        poolclass=pool.NullPool
    )

    with connectable.connect() as connection:
        # Here, the context is used to run migrations
        context.configure(
            connection=connection,
            target_metadata=target_metadata
        )

        with context.begin_transaction():
            context.run_migrations()

# Function to run migrations in 'offline' mode (typically used for generating migration scripts)
def run_migrations_offline():
    """Run migrations in 'offline' mode."""
    url = config.get_main_option("sqlalchemy.url")
    context.configure(
        url=url,
        target_metadata=target_metadata,
        literal_binds=True
    )

    with context.begin_transaction():
        context.run_migrations()

# Main entry point for Alembic's migration logic
if context.is_offline_mode():
    run_migrations_offline()
else:
    run_migrations_online()

