from setuptools import setup, find_packages
import os
import xcap

setup(
    name=xcap__project__,
    version=xcap.__version__,
    description=xcap.__description__,
    long_description=open("README.md").read(),
    long_description_content_type="text/markdown",
    author=xcap.__author__,
    author_email=xcap.__author_email__,
    url=xcap.__repository__,
    packages=find_packages(where="xcap"),  # Looking for packages in the "xcap" folder
    include_package_data=True,
    install_requires=[
        "fastapi",
        "sqlmodel",
        "uvicorn",
        "httpx",   # or aiohttp if you prefer
        "alembic",
        "python-dotenv",  # Optional, for .env support
        "pydantic",  # Ensure compatibility with FastAPI
        "requests",  # If you need to handle HTTP requests elsewhere
    ],
    extras_require={
        "dev": [
            "pytest",         # For testing
            "pytest-asyncio", # For async testing
            "black",          # Code formatter
            "flake8",         # Linter
            "isort",          # Sort imports
        ],
        "docker": [
            "docker",  # For Docker-related utilities (optional)
        ],
    },
    entry_points={
        "console_scripts": [
            "openxcap=openxcap:main",  # Use "openxcap" as the entry point to run the server
        ],
    },
    classifiers=[
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.8",
        "Intended Audience :: Service Providers",
        "License :: OSI Approved :: GNU General Public License v3 (GPLv3)",
        "Operating System :: OS Independent",
    ],
    python_requires=">=3.7",
    include_package_data=True,
)

