from abc import ABC, abstractmethod
from typing import Optional
from xcap.schemas import XCAPData

class BackendInterface(ABC):

    @abstractmethod
    async def get_data(self, resource_path: str) -> Optional[XCAPData]:
        """Retrieve data for a specific resource."""
        pass

    @abstractmethod
    async def store_data(self, resource_path: str, xcap_data: XCAPData) -> XCAPData:
        """Store data for a specific resource."""
        pass

    @abstractmethod
    async def update_data(self, resource_path: str, xcap_data: XCAPData) -> Optional[XCAPData]:
        """Update an existing resource."""
        pass

    @abstractmethod
    async def delete_data(self, resource_path: str) -> bool:
        """Delete data for a specific resource."""
        pass

