from application.configuration import ConfigSection, ConfigSetting
from application.configuration.datatypes import NetworkRangeList, IPAddress
from xcap.configuration.datatypes import XCAPRootURI
from xcap.tls import Certificate, PrivateKey

class AuthenticationConfig(ConfigSection):
    __cfgfile__ = 'config.ini'
    __section__ = 'Authentication'

    type = 'digest'
    cleartext_passwords = True
    default_realm = ConfigSetting(type=str, value=None)
    trusted_peers = ConfigSetting(type=NetworkRangeList, value=NetworkRangeList('none'))


class ServerConfig(ConfigSection):
    __cfgfile__ = 'config.ini'
    __section__ = 'Server'

    address = ConfigSetting(type=IPAddress, value='127.0.0.1')
    port = ConfigSetting(type=int, value=8000)
    root = ConfigSetting(type=XCAPRootURI, value=None)
    backend = ConfigSetting(type=str, value=None)


class TLSConfig(ConfigSection):
    __cfgfile__ = 'config.ini'
    __section__ = 'TLS'

    certificate = ConfigSetting(type=Certificate, value=None)
    private_key = ConfigSetting(type=PrivateKey, value=None)

