from sqlalchemy import create_engine
from sqlalchemy.orm import sessionmaker
from xcap.db.database import Base  # Importing the Base class from models
from alembic.config import Config
from alembic import command
import os

# Database URL configuration
DATABASE_URL = "sqlite:///./test.db"  # Use appropriate path to your database

# Create a database engine
engine = create_engine(DATABASE_URL, connect_args={"check_same_thread": False})

# SessionLocal to be used for DB interactions
SessionLocal = sessionmaker(autocommit=False, autoflush=False, bind=engine)

# Function to initialize the database using Alembic
def init_db():
    alembic_cfg = Config("alembic.ini")  # Alembic configuration
    alembic_cfg.set_main_option("script_location", "migrations")  # Path to migrations
    with engine.connect():
        command.upgrade(alembic_cfg, "head")  # Apply Alembic migrations

    print("Database initialized and migrations applied.")

# Function to create tables manually if not already done
def create_tables():
    if not os.path.exists("test.db"):  # Check if database exists (for SQLite)
        print("Database does not exist. Creating tables...")
        Base.metadata.create_all(bind=engine)  # Create tables from models
        print("Tables created.")
    else:
        print("Database already exists.")

# Main function to initialize and create tables
if __name__ == "__main__":
    create_tables()
    init_db()

