import uvicorn
import sys
from fastapi import FastAPI
from application import log

from xcap.configuration import ServerConfig, TLSConfig
from xcap.db.init_db import init_db
from xcap.routes import xcap_routes
from xcap import __name__,__description__, __version__

class XCAPApp(FastAPI):
    def __init__(self):
        super().__init__(title=__name__, description=__description__, version=__version__)
        self.include_router(xcap_routes.router)
        # self.app.include_router(user_routes.router)  # Uncomment if user_routes is needed
        self.add_event_handler("startup", self.startup)
        self.add_api_route("/", self.read_root, methods=["GET"])

    async def startup(self):
        init_db()
        print("The OpenXCAP app is running... 🚀")

    async def read_root(self):
        return {"message": "Welcome to OpenXCAP!"}


class XCAPServer():
    def __init__(self):
        self.config = ServerConfig

    def run(self, debug=False):
        config = {
            'factory': True,
            'host': self.config.address,
            'port': self.config.root.port,
            'debug': debug,
            'reload': debug,
            'log_level': 'debug' if debug else 'info'
        }

        if self.config.root.startswith('https'):
            certificate, private_key = TLSConfig.certificate, TLSConfig.private_key
            if certificate is None or private_key is None:
                log.critical('The TLS certificate/key could not be loaded')
                sys.exit(1)

            config['ssl_certfile'] = TLSConfig.certificate
            config['ssl_keyfile'] = TLSConfig.private_key

        uvicorn.run("xcap.server:XCAPApp", **config)
