from typing import Optional
from xcap.db.database import get_db_session
from xcap.backend import BackendInterface
from xcap.schemas.xcap_data import XCAPData


async def get_xcap_data(domain: str, namespace: str,  username: str, resource_path: str) -> Optional[XCAPData]:
    """Retrieve XCAP resource data from the selected backend backend."""
    async with get_db_session() as db_session:
        # Use the appropriate backend backend (database, OpenSIPS, etc.)
        backend: BackendInterface = BackendInterface.get_backend("database")  # Modify as needed
        return await backend.get_xcap_data(db_session, domain, namespace, username, resource_path)


async def save_xcap_data(domain: str, namespace: str, username: str, resource_path: str, xcap_data: XCAPData) -> XCAPData:
    """Save new XCAP resource data to the selected backend backend."""
    async with get_db_session() as db_session:
        # Use the appropriate backend backend (database, OpenSIPS, etc.)
        backend: BackendInterface = BackendInterface.get_backend("database")  # Modify as needed
        return await backend.save_xcap_data(db_session, domain, namespace, username, resource_path, xcap_data)


async def update_xcap_data(domain: str, namespace: str, username: str, resource_path: str, xcap_data: XCAPData) -> Optional[XCAPData]:
    """Update an existing XCAP resource."""
    async with get_db_session() as db_session:
        # Use the appropriate backend backend (database, OpenSIPS, etc.)
        backend: BackendInterface = BackendInterface.get_backend("database")  # Modify as needed
        return await backend.update_xcap_data(db_session, domain, namespace, username, resource_path, xcap_data)


async def delete_xcap_data(domain: str, namespace: str, username: str, resource_path: str) -> bool:
    """Delete XCAP resource data from the selected backend backend."""
    async with get_db_session() as db_session:
        # Use the appropriate backend backend (database, OpenSIPS, etc.)
        backend: BackendInterface = BackendInterface.get_backend("database")  # Modify as needed
        return await backend.delete_xcap_data(db_session, domain, namespace, username, resource_id)
