__all__ = ['Certificate', 'PrivateKey']

import ssl
from application import log
from application.process import process

class _FileError(Exception):
    pass


def file_content(filename: str) -> str:
    """Helper function to read file content."""
    path = process.configuration.file(filename)
    if path is None:
        raise _FileError(f'File {filename!r} does not exist')
        try:
            with open(path, 'r') as f:
                return f.read()
        except Exception as e:
            raise _FileError(f'File {filename!r} could not be opened: {e}')


class Certificate:
    """Configuration data type for a TLS certificate."""

    def __new__(cls, value):
        if isinstance(value, str):
            try:
                return ssl.SSLContext(ssl.PROTOCOL_TLS).load_cert_chain(certfile=value)
            except Exception as e:
                log.warning(f'Certificate file {value!r} could not be loaded: {e}')
                return None
        else:
            raise TypeError('value should be a string')


class PrivateKey:
    """Configuration data type for a private key."""

    def __new__(cls, value):
        if isinstance(value, str):
            try:
                return ssl.SSLContext(ssl.PROTOCOL_TLS).load_cert_chain(keyfile=value)
            except Exception as e:
                log.warning(f'Private key file {value!r} could not be loaded: {e}')
                return None
        else:
            raise TypeError('value should be a string')
